@@ -1,13 +1,13 @@
-import matplotlib.pyplot as plt
-import numpy as np
 import warnings
 
+import matplotlib.pyplot as plt
+import numpy as np
+
 from matplotlib.mlab import psd, csd
+from numpy.fft import fft, fftfreq
 from scipy.optimize import minimize
 from scipy import signal
 
-from numpy.fft import fft, fftfreq
-
 class tfest:
     def __init__(self, u, y):
         self.u = u
@@ -19,24 +19,23 @@ class tfest:
         self.nzeros = 0
         self.init_value = 1
 
-    def loss(self, x, nzeros, freq, H, l=0):
+    def loss(self, x, nzeros, freq, H, l1=0):
         """
         x: array of zeros and poles
         nzeros: number of zeros
         freq: frequency
         H: frequency response
-        l: L1 norm
+        l1: L1 norm
 
         return: loss
         """
         zeros = x[:nzeros]
         poles = x[nzeros:]
-        risp = np.array([np.polyval(zeros, s) for s in 1j*freq])
-        risp /= np.array([np.polyval(poles, s) for s in 1j*freq])
-        if l == 0:
+        risp = np.array([np.polyval(zeros, s)/np.polyval(poles, s) for s in 1j*freq])
+        if l1 == 0:
             L = 0
         else:
-            L = l*np.sqrt((x**2).sum())
+            L = l1*np.sqrt((x**2).sum())
         return np.linalg.norm((risp-H).reshape(-1, 1), axis=1).sum() + L
 
     def frequency_response(self, method="h1", time=None):
@@ -72,7 +71,7 @@ class tfest:
         self.H = H
         return self.H, frequency
 
-    def estimate(self, nzeros, npoles, init_value=1, options={'xatol': 1e-3, 'disp': True}, method="h1", time=None, l=0):
+    def estimate(self, nzeros, npoles, init_value=1, options={'xatol': 1e-3, 'disp': True}, method="h1", time=None, l1=0):
         """
         npoles: number of poles
         nzeros: number of zeros
@@ -80,7 +79,7 @@ class tfest:
         options: options for scipy.optimize.minimize
         method: "fft" or "density"
         time: time for fft
-        l: L1 norm
+        l1: L1 norm
 
         return: scipy.optimize.minimize.OptimizeResult
         """
@@ -92,7 +91,7 @@ class tfest:
 
         x0 = [init_value]*(npoles+nzeros)
         H, frequency = self.frequency_response(method=method, time=time)
-        pass_to_loss = lambda x: self.loss(x, nzeros, frequency, H, l)
+        pass_to_loss = lambda x: self.loss(x, nzeros, frequency, H, l1)
         self.res = minimize(pass_to_loss, x0, method='nelder-mead', options=options)
         return self.res
 
@@ -133,8 +132,7 @@ class tfest:
         zeros = self.res.x[:self.nzeros]
         poles = self.res.x[self.nzeros:]
         omega = np.array([(1j*s) for s in self.frequency])
-        risp = np.array([np.polyval(zeros, s) for s in omega])
-        risp /= np.array([np.polyval(poles, s) for s in omega])
+        risp = np.array([np.polyval(zeros, s)/np.polyval(poles, s) for s in omega])
         plt.plot(np.log(risp), label="estimation")
         plt.plot(np.log(self.H), label="train data")
         plt.legend(loc="upper right")
